@@ -77,13 +77,17 @@
 #include "macros.h"
 #include "auto_config.h"
 #include "logging.h"
+#include "device_monitor.h"
 
 #include <config.h>
+#include <glib/gprintf.h>
 #include <glib/gi18n.h>
 
 guint id;
 gboolean echo_on;
+gboolean autoreconnect_on;
 gboolean crlfauto_on;
+gboolean esc_clear_screen_on;
 gboolean timestamp_on = 0;
 GtkWidget *StatusBar;
 GtkWidget *signals[6];
@@ -120,7 +124,9 @@ void help_about_callback(GtkAction *action, gpointer data);
 gboolean Envoie_car(GtkWidget *, GdkEventKey *, gpointer);
 gboolean control_signals_read(void);
 void echo_toggled_callback(GtkAction *action, gpointer data);
+void Autoreconnect_toggled_callback(GtkAction *action, gpointer data);
 void CR_LF_auto_toggled_callback(GtkAction *action, gpointer data);
+void esc_clear_screen_toggled_callback(GtkAction *action, gpointer data);
 void timestamp_toggled_callback(GtkAction *action, gpointer data);
 void view_radio_callback(GtkAction *action, gpointer data);
 void view_hexadecimal_chars_radio_callback(GtkAction* action, gpointer data);
@@ -156,6 +162,7 @@ const GtkActionEntry menu_entries[] =
 	{"ClearScrollback", GTK_STOCK_CLEAR, N_("_Clear scrollback"), "<shift><control>K", NULL, G_CALLBACK(clear_scrollback)},
 	{"SendFile", GTK_STOCK_JUMP_TO, N_("Send _RAW file"), "<shift><control>R", NULL, G_CALLBACK(send_raw_file)},
 	{"SaveFile", GTK_STOCK_SAVE_AS, N_("_Save RAW file"), "", NULL, G_CALLBACK(save_raw_file)},
+        {"SaveAsciiFile", GTK_STOCK_SAVE_AS, N_("Save _ASCII file"), "", NULL, G_CALLBACK(save_ascii_file)},
 
 	/* Edit menu */
 	{"EditCopy", GTK_STOCK_COPY, NULL, "<shift><control>C", NULL, G_CALLBACK(edit_copy_callback)},
@@ -192,7 +199,9 @@ const GtkToggleActionEntry menu_toggle_entries[] =
 {
 	/* Configuration Menu */
 	{"LocalEcho", NULL, N_("Local _echo"), NULL, NULL, G_CALLBACK(echo_toggled_callback), FALSE},
+	{"Autoreconnect", NULL, N_("Autoreconnect"), NULL, NULL, G_CALLBACK(Autoreconnect_toggled_callback), FALSE},
 	{"CRLFauto", NULL, N_("_CR LF auto"), NULL, NULL, G_CALLBACK(CR_LF_auto_toggled_callback), FALSE},
+	{"EscClearScreen", NULL, N_("ESC clear scree_n"), NULL, NULL, G_CALLBACK(esc_clear_screen_toggled_callback), FALSE},
 	{"Timestamp", NULL, N_("Timestamp"), NULL, NULL, G_CALLBACK(timestamp_toggled_callback), FALSE},
 
 	/* View Menu */
@@ -223,6 +232,7 @@ static const char *ui_description =
     "      <menuitem action='ClearScrollback'/>"
     "      <menuitem action='SendFile'/>"
     "      <menuitem action='SaveFile'/>"
+    "      <menuitem action='SaveAsciiFile'/>"
     "      <separator/>"
     "      <menuitem action='FileExit'/>"
     "    </menu>"
@@ -243,7 +253,9 @@ static const char *ui_description =
     "      <menuitem action='ConfigPort'/>"
     "      <menuitem action='ConfigTerminal'/>"
     "      <menuitem action='LocalEcho'/>"
+    "      <menuitem action='Autoreconnect'/>"
     "      <menuitem action='CRLFauto'/>"
+    "      <menuitem action='EscClearScreen'/>"
     "      <menuitem action='Timestamp'/>"
     "      <menuitem action='Macros'/>"
     "      <separator/>"
@@ -385,12 +397,46 @@ void Set_crlfauto(gboolean crlfauto)
 		gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), crlfauto_on);
 }
 
+void Set_autoreconnect_enabled(gboolean autoreconnect_enabled)
+{
+	GtkAction *action;
+
+	autoreconnect_on = autoreconnect_enabled;
+
+	action = gtk_action_group_get_action(action_group, "Autoreconnect");
+	if(action)
+		gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), autoreconnect_on);
+}
+
+void Autoreconnect_toggled_callback(GtkAction *action, gpointer data)
+{
+	autoreconnect_on = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	configure_autoreconnect_enable(autoreconnect_on);
+}
+
 void CR_LF_auto_toggled_callback(GtkAction *action, gpointer data)
 {
 	crlfauto_on = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
 	configure_crlfauto(crlfauto_on);
 }
 
+void Set_esc_clear_screen(gboolean esc_clear_screen)
+{
+	GtkAction *action;
+
+	esc_clear_screen_on = esc_clear_screen;
+
+	action = gtk_action_group_get_action(action_group, "EscClearScreen");
+	if(action)
+		gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), esc_clear_screen_on);
+}
+
+void esc_clear_screen_toggled_callback(GtkAction *action, gpointer data)
+{
+	esc_clear_screen_on = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action));
+	configure_esc_clear_screen(esc_clear_screen_on);
+}
+
 void Set_timestamp(gboolean timestamp)
 {
 	GtkAction *action;
@@ -569,7 +615,7 @@ void create_main_window(void)
 
 	/* send hex char box (hidden when not in use) */
 	Hex_Box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-	label = gtk_label_new(_("Hexadecimal data to send (separator : ';' or space) : "));
+	label = gtk_label_new(_("Hexadecimal data to send (separator: ';' or space): "));
 	gtk_box_pack_start(GTK_BOX(Hex_Box), label, FALSE, FALSE, 5);
 	hex_send_entry = gtk_entry_new();
 	g_signal_connect(GTK_WIDGET(hex_send_entry), "activate", (GCallback)Send_Hexadecimal, NULL);
@@ -623,7 +669,7 @@ void initialize_hexadecimal_display(void)
 	blank_data[bytes_per_line * 3 + 5] = 0;
 }
 
-void put_hexadecimal(gchar *string, guint size)
+void put_hexadecimal(const gchar *string, guint size)
 {
 	static gchar data[128];
 	static gchar data_byte[6];
@@ -690,7 +736,7 @@ void put_hexadecimal(gchar *string, guint size)
 	}
 }
 
-void put_text(gchar *string, guint size)
+void put_text(const gchar *string, guint size)
 {
 	log_chars(string, size);
 	vte_terminal_feed(VTE_TERMINAL(display), string, size);
@@ -704,7 +750,7 @@ gint send_serial(gchar *string, gint len)
 	if(bytes_written > 0)
 	{
 		if(echo_on)
-			put_chars(string, bytes_written, crlfauto_on);
+			put_chars(string, bytes_written, crlfauto_on, esc_clear_screen_on);
 	}
 
 	return bytes_written;
@@ -730,7 +776,7 @@ void help_about_callback(GtkAction *action, gpointer data)
 	gchar *authors[] = {"Julien Schimtt", "Zach Davis", "Florian Euchner", "Stephan Enderlein",
 			    "Kevin Picot", NULL};
 	gchar *comments_program = _("GTKTerm is a simple GTK+ terminal used to communicate with the serial port.");
-	gchar *comments[256];
+	gchar comments[256];
 	GError *error = NULL;
 	GdkPixbuf *logo = NULL;
 
