@@ -71,7 +71,7 @@ gboolean Lis_port(GIOChannel* src, GIOCondition cond, gpointer data)
 		bytes_read = read(serial_port_fd, c, BUFFER_RECEPTION);
 		if(bytes_read > 0)
 		{
-			put_chars(c, bytes_read, config.crlfauto);
+			put_chars(c, bytes_read, config.crlfauto, config.esc_clear_screen);
 
 			if(config.car != -1 && waiting_for_char == TRUE)
 			{
@@ -321,6 +321,16 @@ void configure_crlfauto(gboolean crlfauto)
 	config.crlfauto = crlfauto;
 }
 
+void configure_autoreconnect_enable(gboolean autoreconnect)
+{
+	config.autoreconnect_enabled = autoreconnect;
+}
+
+void configure_esc_clear_screen(gboolean esc_clear_screen)
+{
+	config.esc_clear_screen = esc_clear_screen;
+}
+
 void Close_port(void)
 {
 	if(serial_port_fd != -1)
@@ -352,7 +362,7 @@ void Set_signals(guint param)
 
 	if(ioctl(serial_port_fd, TIOCMGET, &stat_) == -1)
 	{
-		i18n_perror(_("Control signals read"));
+		i18n_perror(_("Control signals read set signals"));
 		return;
 	}
 
@@ -398,7 +408,7 @@ int lis_sig(void)
 			/* Thanks to Elie De Brauwer on ubuntu launchpad */
 			if (errno != EINVAL)
 			{
-				i18n_perror(_("Control signals read"));
+				i18n_perror(_("Control signals read lis_sig"));
 				Close_port();
 			}
 
