@@ -24,6 +24,8 @@ int lis_sig(void);
 void Close_port(void);
 void configure_echo(gboolean);
 void configure_crlfauto(gboolean);
+void configure_autoreconnect_enable(gboolean);
+void configure_esc_clear_screen(gboolean);
 void sendbreak(void);
 gint set_custom_speed(int, int);
 gchar* get_port_string(void);
