@@ -78,6 +78,8 @@ gint *rts_time_before_tx;
 gint *rts_time_after_tx;
 gint *echo;
 gint *crlfauto;
+gint *autoreconnect_enabled;
+gint *esc_clear_screen;
 gint *timestamp;
 cfgList **macro_list = NULL;
 gchar **font;
@@ -111,6 +113,8 @@ cfgStruct cfg[] =
 	{"rs485_rts_time_after_tx", CFG_INT, &rts_time_after_tx},
 	{"echo", CFG_BOOL, &echo},
 	{"crlfauto", CFG_BOOL, &crlfauto},
+	{"autoreconnect_enabled", CFG_BOOL, &autoreconnect_enabled},
+	{"esc_clear_screen", CFG_BOOL, &esc_clear_screen},
 	{"timestamp", CFG_BOOL, &timestamp},
 	{"font", CFG_STRING, &font},
 	{"macros", CFG_STRING_LIST, &macro_list},
@@ -176,6 +180,8 @@ void config_file_init(void)
 void ConfigFlags(void)
 {
 	Set_crlfauto(config.crlfauto);
+	Set_autoreconnect_enabled(config.autoreconnect_enabled);
+	Set_esc_clear_screen(config.esc_clear_screen);
 	Set_timestamp(config.timestamp);
 }
 
@@ -210,7 +216,7 @@ void Config_Port_Fenetre(GtkAction *action, gpointer data)
 		show_message(_("No serial devices found!\n"
 		               "\n"
 		               "Searched the following device path patterns:\n"
-		               "\t/dev/ttyS*\n\t/dev/tts/*\n\t/dev/ttyUSB*\n\t/dev/usb/tts/*\n\n"
+		               "\t/dev/ttyS*\n\t/dev/tts/*\n\t/dev/ttyUSB*\n\t/dev/ttyACM*\n\t/dev/usb/tts/*\n\n"
 		               "Enter a different device path in the 'Port' box.\n"), MSG_WRN);
 	}
 
@@ -973,6 +979,16 @@ gint Load_configuration_from_file(gchar *config_name)
 				else
 					config.crlfauto = FALSE;
 
+				if(autoreconnect_enabled[i] != -1)
+					config.autoreconnect_enabled = (gboolean)autoreconnect_enabled[i];
+				else
+					config.autoreconnect_enabled = FALSE;
+
+				if(esc_clear_screen[i] != -1)
+					config.esc_clear_screen = (gboolean)esc_clear_screen[i];
+				else
+					config.esc_clear_screen = FALSE;
+
 				if(timestamp[i] != -1)
 					config.timestamp = (gboolean)timestamp[i];
 				else
@@ -1199,6 +1215,8 @@ void Hard_default_configuration(void)
 	config.car = DEFAULT_CHAR;
 	config.echo = DEFAULT_ECHO;
 	config.crlfauto = FALSE;
+	config.autoreconnect_enabled = FALSE;
+	config.esc_clear_screen = FALSE;
 	config.timestamp = FALSE;
   config.disable_port_lock = FALSE;
 
@@ -1305,6 +1323,22 @@ void Copy_configuration(int pos)
 	cfgStoreValue(cfg, "crlfauto", string, CFG_INI, pos);
 	g_free(string);
 
+	if(config.autoreconnect_enabled == FALSE)
+		string = g_strdup_printf("False");
+	else
+		string = g_strdup_printf("True");
+
+	cfgStoreValue(cfg, "autoreconnect_enabled", string, CFG_INI, pos);
+	g_free(string);
+
+	if(config.esc_clear_screen == FALSE)
+		string = g_strdup_printf("False");
+	else
+		string = g_strdup_printf("True");
+
+	cfgStoreValue(cfg, "esc_clear_screen", string, CFG_INI, pos);
+	g_free(string);
+
 	if(config.timestamp == FALSE)
 		string = g_strdup_printf("False");
 	else
